#
# spec file for package maven-common-artifact-filters
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-common-artifact-filters
Version:        3.3.2
Release:        2.4
Summary:        Maven Common Artifact Filters
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-util
BuildRequires:  maven-shared-utils
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
A collection of ready-made filters to control inclusion/exclusion of artifacts
during dependency resolution.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%pom_xpath_remove pom:project/pom:parent/pom:relativePath

%build
mkdir -p lib
build-jar-repository -s lib \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-model-builder \
    maven/maven-plugin-api \
    maven-resolver/maven-resolver-api \
    maven-resolver/maven-resolver-util \
    maven-shared-utils/maven-shared-utils \
    org.eclipse.sisu.plexus \
    slf4j/api

%{ant} \
    jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove stray dependency on xmvn tools and parent pom
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.2
- Changes of 3.3.2
  * Bug
    + MSHARED-1130: PatternIncludesArtifactFilters raising NPE for
    patterns w/ wildcards and artifactoid w/ null on any
    coordinate
- Changes of 3.3.1
  * Bug
    + MSHARED-1104: Pattern w/ 4 elements may be GATV or GATC
- Changes of 3.3.0
  * Bug
    + MSHARED-1017: null passed to DependencyFilter in
    EclipseAetherFilterTransformerTest
    + MSHARED-1031: PatternIncludesArtifactFilter#include(Artifact)
    + MSHARED-1077: Common Artifact Filters pattern parsing with
    classifier is broken
  * Task
    + MSHARED-988: Sanitize dependencies
    + MSHARED-1078: Upgrade to Maven Parent 36, to Maven 3.2.5, to
    Java 8 and clean up dependencies
- Changes of 3.2.0
  * Improvement
    + MSHARED-975: Big speed improvements for patterns that do not
    contain any wildcard
- Changes of 3.1.1
  * Bug
    + MSHARED-942: Update JIRA URL for maven-common-artifact-filters
  * Improvement
    + MSHARED-879: make build Reproducible
- Changes of 3.1.0
  * Bug
    + MSHARED-631: Several filters do not preserve order of
    artifacts filtered
- Removed patch:
  * 0001-Remove-Maven-3.0-specific-code.patch
    + not needed with this version
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-common-artifact-filters 3.0.1
- Generate and customize the ant build.xml file
